from fastapi import APIRouter, Response

from xmpp_api.api.types.v1.health import HealthResponse, ReadinessResponse
from xmpp_api.xmpp.component import XmppApiComponentDep


router = APIRouter(prefix="/health")


@router.get("/readiness")
def get_is_ready(
    component: XmppApiComponentDep, response: Response
) -> ReadinessResponse:
    component_ready = component.is_connected()

    response.status_code = 200 if component_ready else 503
    return ReadinessResponse(
        component=component_ready,
    )


@router.get("/healthy")
def get_is_healthy(
    component: XmppApiComponentDep, response: Response
) -> HealthResponse:
    component_ready = component.is_connected()

    response.status_code = 200 if component_ready else 503
    return HealthResponse(
        component=component_ready,
    )
