import uuid
import argparse

from sqlmodel import SQLModel

from xmpp_api.config.config import load_config
from xmpp_api.db import get_session, get_engine
from xmpp_api.db.user import User
from xmpp_api.util.token import generate_token


def main():
    """
    Creates a new user that can create bots
    """

    parser = argparse.ArgumentParser()
    parser.add_argument("--name", required=True, help="Name of the user")
    args = parser.parse_args()

    # Create all tables
    engine = get_engine(load_config())
    SQLModel.metadata.create_all(engine)

    # Create the user
    session = next(get_session(engine))
    user = User(
        id=uuid.uuid4().hex,
        name=args.name,
        token=generate_token(64),
    )
    session.add(user)
    session.commit()

    print(f"User token: {user.token}")
